/*
    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>

    SPDX-License-Identifier: LGPL-2.1-or-later
*/

#ifndef EXTRACTORTEST_H
#define EXTRACTORTEST_H

#include <QObject>

class ExtractorTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
    void test();
};

#endif // EXTRACTORTEST_H
